Resolves the path to the small, realistic example .xlsx
workbook shipped with imuRUN (derived from 'imuGAP”s *_sim datasets), via
base::system.file().
Resolves the path to the small, realistic example .xlsx
workbook shipped with imuRUN (derived from 'imuGAP”s *_sim datasets), via
base::system.file().